<?php
class widgetAuthRegister extends cmsWidget {

    public $is_cacheable = false;

    public function run(){

        if (cmsUser::isLogged()){ return false; }

        $auth = cmsCore::getController('auth');

        if (!$auth->options['is_reg_enabled']){
            return false;
        }

        list($form, $fieldsets) = $this->getRegistrationForm();

        if ($auth->options['reg_captcha']){
            $captcha_html = cmsEventsManager::hook('captcha_html');
        }

        return array(
            'form'         => $form,
            'captcha_html' => isset($captcha_html) ? $captcha_html : false
        );
		
		
	}
		
	public function getRegistrationForm() {
		
		$auth = cmsCore::getController('auth');

        $form = $auth->getForm('registration');

        //
        // Добавляем поле для кода приглашения,
        // если регистрация доступна только по приглашениям
        //
        if ($auth->options['is_reg_invites'] || $auth->request->has('inv')){

            $fieldset_id = $form->addFieldsetToBeginning(!$auth->options['is_reg_invites'] ? '' : LANG_REG_INVITED_ONLY);

            $form->addField($fieldset_id, new fieldString('inv', array(
                'title' => LANG_REG_INVITE_CODE,
                'attributes' => array(
                    'readonly' => !$auth->options['is_reg_invites'] ? true : false
                ),
                'rules' => array(
                    array('required'),
                    array('min_length', 10),
                    array('max_length', 10)
                )
            )));

        }

        //
        // Добавляем поле выбора группы,
        // при наличии публичных групп
        //
        $public_groups = $auth->model_users->getPublicGroups();

        if ($public_groups) {

            $pb_items = array();
            foreach($public_groups as $pb) { $pb_items[ $pb['id'] ] = $pb['title']; }

            $form->addFieldToBeginning('basic',
                new fieldList('group_id', array(
                        'title' => LANG_USER_GROUP,
                        'items' => $pb_items
                    )
                )
            );

        }

        //
        // Добавляем в форму обязательные поля профилей
        //
        $fields = $auth->model_content->setTablePrefix('')->orderBy('ordering')->getRequiredContentFields('{users}');

        // Разбиваем поля по группам
        $fieldsets = cmsForm::mapFieldsToFieldsets($fields);

        // Добавляем поля в форму
        foreach($fieldsets as $fieldset){

            $fieldset_id = $form->addFieldset($fieldset['title']);

            foreach($fieldset['fields'] as $field){

                if ($field['name'] == 'nickname') {
                    $form->addFieldToBeginning('basic', $field['handler']); continue;
                }

                $form->addField($fieldset_id, $field['handler']);

            }

        }

        return array($form, $fieldsets);

    }
		

  

}
